<?php

/**
 * Helper class.
 */
class TmgmtCdtHelper {

  /**
   * Check if is a json.
   */
  public static function isJson($data) {
        // @codingStandardsIgnoreStart
        // Need native json format.
        if (is_string($data) && is_array(json_decode($data, TRUE)) && (json_last_error() === JSON_ERROR_NONE)) { 
            return TRUE;
        } else {
            return FALSE;
        }
        // @codingStandardsIgnoreEnd
  }

  /**
   * WatchdogDebug.
   */
  public static function watchdogDebug($var, $label = 'label') {

    $bt = debug_backtrace();
    $caller = array_shift($bt);

    watchdog(
        $label,
        '<pre>@file: @line</pre>@label: <pre>@var</pre>',
        array(
          '@label' => $label,
          '@var' => print_r($var, TRUE),
          '@file' => $caller['file'],
          '@line' => $caller['line'],
        ),
        WATCHDOG_DEBUG
    );
  }

  /**
   * All fields used in this module.
   */
  public static function getFields() {
    return array(
      'tmgmt_job' => array(
        'cdt_correlation_id' => array(
          'label' => 'Correlation ID',
          'description' => 'ID returned after a successful request to CDT.',
          'db' => array(
            'type' => 'varchar',
            'length' => 32,
          ),
          'entity' => array(
            'type' => 'text',
          ),
        ),
        'cdt_request_identifier' => array(
          'label' => 'Request identifier',
          'description' => 'Seconde ID returned by CDT.',
          'db' => array(
            'type' => 'varchar',
            'length' => 32,
          ),
          'entity' => array(
            'type' => 'text',
          ),
        ),
        'cdt_request_params' => array(
          'label' => 'Request parameters',
          'description' => 'Parameters used to make the request to CDT.',
          'db' => array(
            'type' => 'text',
            'size' => 'medium',
          ),
          'entity' => array(
            'type' => 'text',
          ),
        ),
        'cdt_response' => array(
          'label' => 'Response',
          'description' => 'Response (translations) from CDT.',
          'db' => array(
            'type' => 'text',
            'size' => 'medium',
          ),
          'entity' => array(
            'type' => 'text',
          ),
        ),
      ),
      'tmgmt_job_item' => array(
        'cdt_source_language' => array(
          'label' => 'Source language',
          'description' => 'Source language.',
          'db' => array(
            'type' => 'varchar',
            'length' => 12,
          ),
          'entity' => array(
            'type' => 'text',
          ),
        ),
        'cdt_target_language' => array(
          'label' => 'Target language',
          'description' => 'Target language.',
          'db' => array(
            'type' => 'varchar',
            'length' => 12,
          ),
          'entity' => array(
            'type' => 'text',
          ),
        ),
        'cdt_character_count' => array(
          'label' => 'Character count',
          'description' => 'Character count.',
          'db' => array(
            'type' => 'int',
          ),
          'entity' => array(
            'type' => 'integer',
          ),
        ),
        'cdt_settings' => array(
          'label' => 'Settings',
          'description' => 'Settings.',
          'db' => array(
            'type' => 'text',
            'size' => 'medium',
            'serialize' => TRUE,
          ),
          'entity' => array(
            'type' => 'text',
          ),

        ),
      ),
    );
  }

}
